@@ -1,8 +1,7 @@
 package Mira::Model::Base;
-$Mira::Model::Base::VERSION = '00.07.56';
+$Mira::Model::Base::VERSION = '0.07';
 
-use strict;
-use warnings;
+use Data::Dumper;
 use 5.012;
 
 sub new {
@@ -20,6 +19,7 @@ sub add {
 
   $self->{$utid} = $values;
 
+#  %$self = (%$self , %$utid);
 }
 
 1;
