@@ -1,8 +1,7 @@
 package Mira::Model::Content;
 $Mira::Model::Content::VERSION = '0.07';
 
-use strict;
-use warnings;
+use Data::Dumper;
 use 5.012;
 
 use File::Spec::Functions;
