@@ -1,8 +1,7 @@
 package Mira::Model::Floor;
-$Mira::Model::Floor::VERSION = '00.07.56';
+$Mira::Model::Floor::VERSION = '0.07';
 
-use strict;
-use warnings;
+use Data::Dumper;
 use 5.012;
 
 sub new {
